@@ -24,19 +24,20 @@ PKCS7_SIGNED_ENVELOPED = m2.PKCS7_SIGNED_ENVELOPED  # Deprecated
 PKCS7_DATA = m2.PKCS7_DATA  # type: int
 
 
-class PKCS7_Error(Exception):  # noqa
+class PKCS7_Error(Exception):
     pass
 
 m2.pkcs7_init(PKCS7_Error)
 
 
-class PKCS7:
+class PKCS7(object):
 
     m2_pkcs7_free = m2.pkcs7_free
 
     def __init__(self, pkcs7=None, _pyfree=0):
         # type: (Optional[bytes], int) -> None
-        """
+        """PKCS7 object.
+
         :param pkcs7: binary representation of
                the OpenSSL type PKCS7
         """
@@ -78,65 +79,41 @@ class PKCS7:
 
 def load_pkcs7(p7file):
     # type: (AnyStr) -> PKCS7
-    bio = m2.bio_new_file(p7file, 'r')
-    if bio is None:
-        raise BIO.BIOError(Err.get_error())
+    with BIO.openfile(p7file, 'r') as bio:
+        p7_ptr = m2.pkcs7_read_bio(bio.bio)
 
-    try:
-        p7_ptr = m2.pkcs7_read_bio(bio)
-    finally:
-        m2.bio_free(bio)
-
-    if p7_ptr is None:
-        raise PKCS7_Error(Err.get_error())
     return PKCS7(p7_ptr, 1)
 
 
 def load_pkcs7_der(p7file):
     # type: (AnyStr) -> PKCS7
-    bio = m2.bio_new_file(p7file, 'r')
-    if bio is None:
-        raise BIO.BIOError(Err.get_error())
+    with BIO.openfile(p7file, 'rb') as bio:
+        p7_ptr = m2.pkcs7_read_bio_der(bio.bio)
 
-    try:
-        p7_ptr = m2.pkcs7_read_bio_der(bio)
-    finally:
-        m2.bio_free(bio)
-
-    if p7_ptr is None:
-        raise PKCS7_Error(Err.get_error())
     return PKCS7(p7_ptr, 1)
 
 
 def load_pkcs7_bio(p7_bio):
     # type: (BIO.BIO) -> PKCS7
     p7_ptr = m2.pkcs7_read_bio(p7_bio._ptr())
-    if p7_ptr is None:
-        raise PKCS7_Error(Err.get_error())
     return PKCS7(p7_ptr, 1)
 
 
 def load_pkcs7_bio_der(p7_bio):
     # type: (BIO.BIO) -> PKCS7
     p7_ptr = m2.pkcs7_read_bio_der(p7_bio._ptr())
-    if p7_ptr is None:
-        raise PKCS7_Error(Err.get_error())
     return PKCS7(p7_ptr, 1)
 
 
 def smime_load_pkcs7(p7file):
     # type: (AnyStr) -> PKCS7
     bio = m2.bio_new_file(p7file, 'r')
-    if bio is None:
-        raise BIO.BIOError(Err.get_error())
 
     try:
         p7_ptr, bio_ptr = m2.smime_read_pkcs7(bio)
     finally:
         m2.bio_free(bio)
 
-    if p7_ptr is None:
-        raise SMIME_Error(Err.get_error())
     if bio_ptr is None:
         return PKCS7(p7_ptr, 1), None
     else:
@@ -154,8 +131,7 @@ def smime_load_pkcs7_bio(p7_bio):
         return PKCS7(p7_ptr, 1), BIO.BIO(bio_ptr, 1)
 
 
-class Cipher:
-
+class Cipher(object):
     """Object interface to EVP_CIPHER without all the frills of
     M2Crypto.EVP.Cipher.
     """
@@ -171,13 +147,14 @@ class Cipher:
         return self.cipher
 
 
-class SMIME_Error(Exception):  # noqa
+class SMIME_Error(Exception):
     pass
 
 m2.smime_init(SMIME_Error)
 
+
 # FIXME class has no __init__ method
-class SMIME:
+class SMIME(object):
     def load_key(self, keyfile, certfile=None,
                  callback=util.passphrase_callback):
         # type: (AnyStr, Optional[AnyStr], Callable) -> None
@@ -232,10 +209,10 @@ class SMIME:
             raise SMIME_Error('no cipher: use set_cipher()')
         if not hasattr(self, 'x509_stack'):
             raise SMIME_Error('no recipient certs: use set_x509_stack()')
+
         pkcs7 = m2.pkcs7_encrypt(self.x509_stack._ptr(), data_bio._ptr(),
                                  self.cipher._ptr(), flags)
-        if pkcs7 is None:
-            raise SMIME_Error(Err.get_error())
+
         return PKCS7(pkcs7, 1)
 
     def decrypt(self, pkcs7, flags=0):
@@ -246,8 +223,6 @@ class SMIME:
             raise SMIME_Error('no certificate: load_key() used incorrectly?')
         blob = m2.pkcs7_decrypt(pkcs7._ptr(), self.pkey._ptr(),
                                 self.x509._ptr(), flags)
-        if blob is None:
-            raise SMIME_Error(Err.get_error())
         return blob
 
     def sign(self, data_bio, flags=0, algo='sha1'):
@@ -264,14 +239,10 @@ class SMIME:
             pkcs7 = m2.pkcs7_sign1(self.x509._ptr(), self.pkey._ptr(),
                                    self.x509_stack._ptr(),
                                    data_bio._ptr(), hash(), flags)
-            if pkcs7 is None:
-                raise SMIME_Error(Err.get_error())
             return PKCS7(pkcs7, 1)
         else:
             pkcs7 = m2.pkcs7_sign0(self.x509._ptr(), self.pkey._ptr(),
                                    data_bio._ptr(), hash(), flags)
-            if pkcs7 is None:
-                raise SMIME_Error(Err.get_error())
             return PKCS7(pkcs7, 1)
 
     def verify(self, pkcs7, data_bio=None, flags=0):
@@ -289,8 +260,6 @@ class SMIME:
             blob = m2.pkcs7_verify1(p7, self.x509_stack._ptr(),
                                     self.x509_store._ptr(),
                                     data_bio._ptr(), flags)
-        if blob is None:
-            raise SMIME_Error(Err.get_error())
         return blob
 
     def write(self, out_bio, pkcs7, data_bio=None, flags=0):
